
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef mouse3d_MSG_LIB_H
#define mouse3d_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "mouse3dType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  MOUSE3D_MBOX_NAME                  genomInstanceName("mouse3d")

#define  MOUSE3D_MAX_RQST_SIZE              1024

#define  MOUSE3D_MBOX_RQST_SIZE       \
 (BUF_SIZE(MOUSE3D_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  MOUSE3D_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  MOUSE3D_MAX_REPLY_SIZE             8

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  MOUSE3D_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(MOUSE3D_MAX_REPLY_SIZE) \
   + BUF_SIZE(MOUSE3D_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define MOUSE3D_INIT_RQST 0
#define MOUSE3D_EXPORT_RQST 1
#define MOUSE3D_STOP_RQST 2
#define MOUSE3D_BINDINGS_RQST 3
#define MOUSE3D_GAINS_RQST 4
#define MOUSE3D_THRESHOLDS_RQST 5
#define MOUSE3D_ABORT_RQST 6


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS mouse3dClientInit (CLIENT_ID *pClientId);

STATUS mouse3dClientEnd (CLIENT_ID clientId);

int mouse3dAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int mouse3dAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int mouse3dAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS mouse3dInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 mouse3d_path *(in_device),
					 int replyTimeOut);

extern int mouse3dInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int mouse3dInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					mouse3d_path *(in_device), 
					
					int *activity, int *bilan);

extern int mouse3dInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					mouse3d_path *(in_device), 
					
					int *activity,
					int *bilan);




extern STATUS mouse3dExportRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int mouse3dExportReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int mouse3dExportRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int mouse3dExportRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS mouse3dStopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int mouse3dStopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int mouse3dStopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS mouse3dBindingsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 mouse3d_bindings *(in_bindings),
					 int replyTimeOut);

int mouse3dBindingsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int mouse3dBindingsRqstAndRcv (CLIENT_ID clientId, 
				 mouse3d_bindings *(in_bindings), 
				 
				 int *bilan);




extern STATUS mouse3dGainsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 mouse3d_gains *(in_gains),
					 int replyTimeOut);

int mouse3dGainsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int mouse3dGainsRqstAndRcv (CLIENT_ID clientId, 
				 mouse3d_gains *(in_gains), 
				 
				 int *bilan);




extern STATUS mouse3dThresholdsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 mouse3d_thresholds *(in_thresholds),
					 int replyTimeOut);

int mouse3dThresholdsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int mouse3dThresholdsRqstAndRcv (CLIENT_ID clientId, 
				 mouse3d_thresholds *(in_thresholds), 
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* mouse3d_MSG_LIB_H */

